//  Beispiel 6.5.4 "A/D Wandler 18 bit"
//  
//  In diesem Beispiel wird sowohl mit dem internen 10bit ADC 
//  als auch dem I2C 18bit ADC gemessen und die Spannung auf dem OLED angezeigt.
//
//  Unter Verwendung der IoT Brick Library

#include <all_IoT.h>


//Korrekturfaktor berechnen: Korrekturfaktor = UMess(Multimeter) / U(Anzeige Brick)
const float Correction_10bit = 1.0679; //hier Korrketurfaktor für 10bit ADC definieren
const float Correction_18bit = 1.0067; //hier Korrketurfaktor für 18bit ADC definieren


void setup(void)
{
  IoT_Init(true);
  Serial.println("18 bit ADC versus 10 bit ADC");  
  Wire.begin();
  delay(2000);
}

void loop(void)
{
  int analogIN_10bit = analogRead(IoT_Analog10bit);    // Liest Spannung als Rohwert: 0 = 0V, 1023 = 1V-1LSB 
  double UMess_10bit = ((double)analogIN_10bit/1024) * 10.0;  // Umrechnen in Volt analogIN_10bit/Auflösung (*1Volt), *10 wegen 10:1 Teiler am ADC
  // Die nächste Zeile zur Ermittlung des Korrekturfaktors mittels Multimeter-Messung auskommentieren
  UMess_10bit = UMess_10bit*Correction_10bit;  // Korrekturfaktor einrechnen (waehrend Abgleich auskommentieren)
  String UMess_10bit_str = strrealform(UMess_10bit, 32, 1, 2, false, false); // Spannungswert in String umwandeln für OLED Ausgabe mit 2 Nachkommastellen
  
  Serial.print("10 bit:\t");
  Serial.print(UMess_10bit);
  Serial.println(" V\t");

  double analogIN_18bit = IoT_ADC18bit.getDouble();       // Liest Spannung als Double-Werte aus I2C ADC, Eingangsbereich: 0 bis 2,048V
  double UMess_18bit = analogIN_18bit * 10.0;    // *10 wegen 10:1 Teiler am ADC
  // Die nächste Zeile zur Ermittlung des Korrekturfaktors mittels Multimeter-Messung bitte auskommentieren!
  UMess_18bit = UMess_18bit*Correction_18bit;  // Korrekturfaktor einrechnen (waehrend Abgleich auskommentieren)
  String UMess_18bit_str = strrealform(UMess_18bit, 32, 1, 4, false, false); // Spannungswert in String umwandeln für OLED Ausgabe mit 4 Nachkommastellen

  Serial.print("18 bit:\t");
  Serial.print(UMess_18bit_str);
  Serial.println(" V\t");
  Serial.println();
 
  IoT_DisplayClear(16);                                           // OLED Display löschen (16 Punkt Schrift)

  IoT_DisplayAlignText(TEXT_ALIGN_LEFT);
  IoT_DisplayDrawText(0, 0, "18 bit: ");
  IoT_DisplayAlignText(TEXT_ALIGN_RIGHT);
  IoT_DisplayDrawText(127, 0, UMess_18bit_str + " V");

  IoT_DisplayAlignText(TEXT_ALIGN_LEFT);
  IoT_DisplayDrawText(0, 32, "10 bit: ");
  IoT_DisplayAlignText(TEXT_ALIGN_RIGHT);
  IoT_DisplayDrawText(127, 32, UMess_10bit_str + " V");
  
  IoT_DisplayUpdate();                                              // OLED-Anzeige aktualisieren
  
  delay(1000);
}





